"use strict";
var parser_1 = require('graphql/language/parser');
function parseDocument(doc) {
    var parsed = parser_1.parse(doc);
    if (!parsed || parsed.kind !== 'Document') {
        throw new Error('Not a valid GraphQL document.');
    }
    return parsed;
}
exports.parseDocument = parseDocument;
function parseDefinition(definition) {
    var parsedDocument = parseDocument(definition);
    if (parsedDocument.definitions.length !== 1) {
        throw new Error('Must have exactly one definition in document.');
    }
    return parsedDocument.definitions[0];
}
function parseFragment(fragment) {
    var parsedFragment = parseDefinition(fragment);
    if (parsedFragment.kind !== 'FragmentDefinition') {
        throw new Error('Must be a fragment.');
    }
    return parsedFragment;
}
exports.parseFragment = parseFragment;
function parseQuery(query) {
    var queryDefinition = parseDefinition(query);
    if (queryDefinition.kind !== 'OperationDefinition' && queryDefinition.operation !== 'query') {
        throw new Error('Definition must be a query.');
    }
    return queryDefinition;
}
exports.parseQuery = parseQuery;
function parseMutation(mutation) {
    var mutationDefinition = parseDefinition(mutation);
    if (mutationDefinition.kind !== 'OperationDefinition' && mutationDefinition.operation !== 'mutation') {
        throw new Error('Definition must be a mutation.');
    }
    return mutationDefinition;
}
exports.parseMutation = parseMutation;
//# sourceMappingURL=parser.js.map