"use strict";
var chai = require('chai');
var assert = chai.assert;
var store_1 = require('../src/store');
describe('createApolloStore', function () {
    it('does not require any arguments', function () {
        var store = store_1.createApolloStore();
        assert.isDefined(store);
    });
    it('has a default root key', function () {
        var store = store_1.createApolloStore();
        assert.deepEqual(store.getState()['apollo'], {
            queries: {},
            mutations: {},
            data: {},
        });
    });
    it('can take a custom root key', function () {
        var store = store_1.createApolloStore({
            reduxRootKey: 'test',
        });
        assert.deepEqual(store.getState()['test'], {
            queries: {},
            mutations: {},
            data: {},
        });
    });
    it('can be rehydrated from the server', function () {
        var initialState = {
            apollo: {
                queries: {
                    'test.0': true,
                },
                mutations: {},
                data: {
                    'test.0': true,
                },
            },
        };
        var store = store_1.createApolloStore({
            initialState: initialState,
        });
        assert.deepEqual(store.getState(), initialState);
    });
});
//# sourceMappingURL=store.js.map